@@ -53,7 +53,7 @@ class CTemplate {
 
   bool SaveBytecode(const char *filename);
 
-  bool Render(const CTPP::CDT &params, std::string *result);
+  bool Render(CTPP::CDT *params, std::string *result);
 
   std::string last_error_message() const { return last_error_message_; }
 
